Fits the exponential expression to the concentration evolution
C(t) = C_m + (C_z - C_m) exp(-b * t)
flux_fitting_hm(
conc_df_cut,
conc_df,
f_conc,
f_start,
f_fluxid,
cz_window,
b_window,
roll_width,
t_zero
)a dataframe with the slope at t zero, modeled concentration over time and exponential expression parameters
dataframe of gas concentration over time, cut
dataframe of gas concentration over time
column with gas concentration
column with datetime when the measurement started
column with ID of each flux
window used to calculate Cz, at the beginning of cut window
window to estimate b. It is an interval after tz where it is assumed that C fits the data perfectly
width of the rolling mean for CO2 when looking for tz, ideally same as cz_window
time at which the slope should be calculated (for quadratic fit)
Pedersen, A.R., Petersen, S.O., Schelde, K., 2010. A comprehensive approach to soil-atmosphere trace-gas flux estimation with static chambers. European Journal of Soil Science 61, 888–902. https://doi.org/10.1111/j.1365-2389.2010.01291.x
Hutchinson, G.L., Mosier, A.R., 1981. Improved Soil Cover Method for Field Measurement of Nitrous Oxide Fluxes. Soil Science Society of America Journal 45, 311–316. https://doi.org/10.2136/sssaj1981.03615995004500020017x