Learn R Programming

fluxible (version 1.3.4)

flux_fitting_lm: linear fit to gas concentration over time

Description

fits a linear model to the gas concentration over time

Usage

flux_fitting_lm(conc_df_cut, conc_df, f_conc, f_fluxid)

Value

a df with the modeled gas concentration, slope, intercept, std error, r square and p value of the linear model

Arguments

conc_df_cut

dataframe of gas concentration over time, cut

conc_df

dataframe of gas concentration over time

f_conc

column with gas concentration

f_fluxid

column with ID of each flux