Fits an exponential expression to the concentration evolution
flux_fitting_zhao18(
conc_df_cut,
conc_df,
f_conc,
f_start,
f_fluxid,
cz_window,
b_window,
a_window,
roll_width
)a dataframe with the slope at t zero, modeled concentration over time and exponential expression parameters
dataframe of gas concentration over time, cut
dataframe of gas concentration over time
column with gas concentration
column with datetime when the measurement started
column with ID of each flux
window used to calculate Cz, at the beginning of cut window
window to estimate b. It is an interval after tz where it is assumed that C fits the data perfectly
window at the end of the flux to estimate a
width of the rolling mean for CO2 when looking for tz, ideally same as cz_window
Zhao, P., Hammerle, A., Zeeman, M., Wohlfahrt, G., 2018. On the calculation of daytime CO2 fluxes measured by automated closed transparent chambers. Agricultural and Forest Meteorology 263, 267–275. https://doi.org/10.1016/j.agrformet.2018.08.022