checking that arguments and columns are in the correct class
flux_fun_check(args, fn, msg, name_df = NA)list of arguments or dataframe to check
list of functions used to check (is.numeric, is.character, ...)
list of messages to return in case of failed check
in case args is a df with selected columns to check origdf is the original df to take the name from for a more obvious error message
Adam Klimes