Provides the f_end column for flux_match
flux_match_col(field_record, start_col, end_col, name_field_record)dataframe recording which measurement happened when. Has to contain at least a column containing the start of each measurement, and any other column identifying the measurements.
start column in field_record (ymd_hms format)
end column in field_record (ymd_hms format)
name of the df (for error message)