Learn R Programming

fluxible (version 1.3.4)

flux_param_exp: prepares text to print for flux_plot function

Description

creates a df with quality flags and quality diagnostics to print on the plots produced by flux_plot. flux_param_lm is for fit in the lm family (linear and quadratic) flux_param_exp is for the exponential fit

Usage

flux_param_exp(slopes_df, f_datetime)

Arguments

slopes_df

the slopes_df that is being provided to flux_plot

f_datetime

column with datetime of each data point