selecting linear slope with kappamax method
flux_quality_kappamax(
slopes_df,
f_slope,
f_fit,
f_fluxid,
f_slope_lm,
f_fit_lm,
f_b,
force_exp,
fit_type,
instr_error,
name_df
)dataset containing slopes
column containing the slope of each flux (as calculated by the flux_fitting function)
column containing the modeled data (exponential fits)
column of ID for each measurement
column containing the linear slope of each flux
column with the fit of the linear model.
column containing the b parameter of the exponential expression
vector of fluxIDs for which the exponential slope should be used by the user's decision (kappamax method)
model fitted to the data, linear, quadratic or exponential.
Will be automatically filled if slopes_df was produced using
flux_fitting
error of the instrument, in the same unit as the gas concentration
name of slopes_df