indicates if fluxes should be discarded or replaced by 0 according to parameters set by user. flux_quality_lm is for the model of the lm family. flux_quality_exp is for the exponential model.
flux_quality_qua(
slopes_df,
f_fluxid,
f_slope,
f_pvalue,
f_rsquared,
f_slope_lm,
force_discard,
force_ok,
force_zero,
force_lm,
gfactor_threshold,
pvalue_threshold,
rsquared_threshold,
name_df
)same dataframe with added flag and corrected slopes columns
dataset containing slopes, fluxID, p.value and r.squared
column of ID for each measurement
column containing the slope of each flux (as calculated by the flux_fitting function)
column containing the p-value of each flux
column containing the r squared to be used for the quality assessment
column containing the linear slope of each flux (as calculated by the flux_fitting function)
vector of fluxIDs that should be discarded by the user's decision
vector of fluxIDs for which the user wants to keep the calculated slope despite a bad quality flag
vector of fluxIDs that should be replaced by zero by the user's decision
vector of fluxIDs for which the linear slope should be used by the user's decision
threshold for the g-factor. Defines a window
with its opposite outside which the flux will be flagged discard.
threshold of p-value below which the change of gas concentration over time is considered not significant (user decided)
threshold of r squared value below which the linear model is considered an unsatisfactory fit
name of slopes_df (used for error message)