powered by
Measurements meta data as recorded on the field at site Liahovden
record_liahovden
A tibble with 138 rows and 3 variables
Unique ID of the turf in which the measurement took place.
Type of measurement: ecosystems respiration (ER) or net ecosystem exchange (NEE).
Round of measurement.
Datetime at which the measurement was started.
Run the code above in your browser using DataLab