Provides a table of how many fluxes were attributed
which quality flag. This function is incorporated in
flux_quality as a message, but can be used alone to extract
a dataframe with the flag count.
a dataframe with the number of fluxes for each quality flags
and their proportion to the total
Arguments
flags_df
dataframe of flux slopes
f_fluxid
column containing fluxes unique ID
f_quality_flag
column containing the quality flags
f_flags
list of flags used in the dataset
(if different from default from flux_quality).
If not provided, it will list only the flags that are
present in the dataset (no showing 0).