Prepares the fluxes for plotting.
flux_fortify(
slopes_df,
f_conc,
f_datetime,
f_ylim_upper,
f_ylim_lower,
f_facetid,
y_text_position
)dataset containing slopes, with flags produced by flux_quality
column with gas concentration
column with datetime of each data point
y axis upper limit
y axis lower limit
character vector of columns to use as facet IDs. Note that
they will be united, and that has to result in a unique facet ID for each
measurement. Default is f_fluxid