creates a df with quality flags and quality diagnostics to print on the plots produced by flux_plot. flux_param_lm is for fit in the lm family (linear and quadratic) flux_param_exp is for the exponential fit
flux_param_exp(slopes_df, f_datetime)the slopes_df that is being provided to flux_plot
column with datetime of each data point