indicates if fluxes should be discarded or replaced by 0 according to parameters set by user. flux_quality_lm is for the model of the lm family. flux_quality_exp is for the exponential model.
flux_quality_exp(
slopes_df,
f_conc,
f_fluxid,
f_slope,
f_time,
f_fit,
f_slope_lm,
f_b,
force_discard,
force_ok,
force_zero,
force_lm,
gfactor_threshold,
rmse_threshold,
cor_threshold,
b_threshold,
name_df
)same dataframe with added flag and corrected slopes columns
dataset containing slopes, fluxID, and parameters of the exponential expression
column with gas concentration
column of ID for each measurement
column containing the slope of each flux (as calculated by the flux_fitting function)
column containing the time of each measurement in seconds
column containing the modeled data
column containing the linear slope of each flux (as calculated by the flux_fitting function)
column containing the b parameter of the exponential expression
vector of fluxIDs that should be discarded by the user's decision
vector of fluxIDs for which the user wants to keep the calculated slope despite a bad quality flag
vector of fluxIDs that should be replaced by zero by the user's decision
vector of fluxIDs for which the linear slope should be used by the user's decision
threshold for the g-factor. Defines a window
with its opposite outside which the flux will be flagged discard.
threshold for the RMSE of each flux above which the fit is considered unsatisfactory
threshold for the correlation coefficient of gas concentration with time below which the correlation is considered non significant
threshold for the b parameter. Defines a window with its opposite inside which the fit is considered good enough.
name of slopes_df